/*******************************************************************************
Copyright © 2024 Sebastian Roith

Licensed under CC BY 4.0. To view a copy of this license, visit http://creativecommons.org/licenses/by/4.0/
*******************************************************************************/

(function(window) {

const TABLES = [
    { "name": "WEITSPRUNG", "primary": ["name", "sprungweite"], "table": [
        ["name", "versuch", "sprungweite", "guteLandung"],
        ["Antonio", 1, 4.15, 1],
        ["Berta",   1, 0, 0],
        ["Cemal",   1, 3.53, 0],
        ["Dora",    1, 2, 0],
        ["Elena",   1, 3.64, 1],
        ["Antonio", 2, 0, 1],
        ["Cemal",   2, 4, 1],
        ["Dora",    2, 3.42, 0],
        ["Elena",   2, 0, 1],
        ["Berta",   2, 3.06, 0],
        ["Berta",   3, 3.24, 1],
        ["Antonio", 3, 0, 0],
        ["Elena",   3, 4.16, 1],
        ["Cemal",   3, 3.81, 0],
        ["Dora",    3, 0, 0]
    ] }
];

const LEVELS = [
    {
        "task": "<p>In der Tabelle <code>WEITSPRUNG</code> sind die Ergebnisse beim Weitspringen in Metern eingetragen. Alle hatten drei Versuche. Es kommt schnell mal vor, dass jemand übertritt. Dann wird der Versuch als Sprungweite als 0 m gewertet. Der Wahrheitswert <code>guteLandung</code> gibt an, ob die Landung ideal gelungen ist. Nicht ideal wäre beispielsweise ein Abstützen mit den Händen nach hinten, was unnötigerweise zu einer geringeren Weite führt.</p><p>Mache dich zunächst mit der Datenbanktabelle vertraut. Schreibe dazu zuerst eine Abfrage, die dir eine der Datenbanktabelle möglichst ähnliche Ergebnistabelle liefert. Führe sie aus und schaue dir die Ergebnistabelle genau an. Fülle dann einen Lückentext richtig aus.</p>",
        "tables": TABLES,
        "locked": true,
        "checkCode": [
            { "type": "keyword", "value": "select", "max": 1, "fine": 0, "msg": "In dieser Aufgabe sind verschachtelte Abfragen nicht erlaubt…" },
            { "type": "keyword", "value": "as", "max": 0, "fine": 0, "msg": "In dieser Aufgabe ist „AS“ nicht erlaubt…" },
            { "type": "keyword", "value": "and", "max": 0, "fine": 0, "msg": "In dieser Aufgabe ist „AND“ nicht erlaubt…" },
            { "type": "keyword", "value": "or", "max": 0, "fine": 0, "msg": "In dieser Aufgabe ist „OR“ nicht erlaubt…" },
            { "type": "keyword", "value": "not", "max": 0, "fine": 0, "msg": "In dieser Aufgabe ist „NOT“ nicht erlaubt…" },
            { "type": "keyword", "value": "order", "max": 0, "fine": 0, "msg": "In dieser Aufgabe ist „ORDER BY“ nicht erlaubt…" }
        ],
        "checkTermination": [
            { "type": "sameResult", "value": "SELECT * FROM WEITSPRUNG", "fine": 1, "msg": "Die Ergebnistabelle dieser Abfrage entspricht nicht bestmöglich der Datenbanktabelle…" },
            { "type": "accept", "unlock": true }
        ],
        "questionWrongFine": 1,
        "question": {
            "html": "Fülle die Lücken richtig aus:",
            "choices": [
                { "selectalways": true, "html": "Nur ", "type": "text", "unit": " ist bei jedem Versuch eine gute Landung gelungen.", "accept": "Elena", "correct": true },
                { "selectalways": true, "html": "", "type": "text", "unit": " hat keine einzige gute Landung geschafft.", "accept": "Dora", "correct": true },
                { "selectalways": true, "html": "Antonio hat bei ", "type": "number", "min": 0, "max": 10, "step": 0.01, "accept": "1", "unit": " Versuch(en) eine gute Landung geschafft und nicht übertreten.", "correct": true },
                { "selectalways": true, "html": "Beispielsweise ", "type": "text", "unit": " hat bei mindestens einem Versuch übertreten und zugleich keine gute Landung hingelegt.", "accept": ["Berta", "Antonio", "Dora"], "correct": true }
            ]
        }
    },
    {
        "task": "<p>Mittlerweile kennst du ja bereits eine Möglichkeit, die Auswertung der Daten an das Datenbankmanagementsystem auszulagern. Dazu musst du nur eine Abfrage mit einere Gleichung als Auswahlbedingung formulieren.</p><p>Jedoch war keine der Fragen aus dem Lückentext eben allein durch eine solche Abfrage zu lösen. Es gilt also, noch mehr Möglichkeiten zu lernen. Bevor wir uns aber an solch komplexere Abfragen heranwagen, müssen wir die einfachen Auswahlbedingungen weiter vertiefen.</p><p>Beispielsweise das kannst du bereits: Schreibe eine Abfrage mit einer geeigneten Gleichung als Auswahlbedingung, die alle Datensätze zu Sprüngen liefert, bei denen die Landung gut gelang.</p>",
        "code": "SELECT * FROM WEITSPRUNG",
        "keepCode": true,
        "readonly": false,
        "tables": TABLES,
        "locked": true,
        "checkCode": [
            { "type": "compareQuery", "value": "=", "substring": true, "fine": 1, "msg": "Formuliere eine Abfrage mit einer Gleichung als Auswahlbedingung!" },
            { "type": "keyword", "value": "select", "max": 1, "fine": 0, "msg": "In dieser Aufgabe sind verschachtelte Abfragen nicht erlaubt…" },
            { "type": "keyword", "value": "as", "max": 0, "fine": 0, "msg": "In dieser Aufgabe ist „AS“ nicht erlaubt…" },
            { "type": "keyword", "value": "and", "max": 0, "fine": 0, "msg": "In dieser Aufgabe ist „AND“ nicht erlaubt…" },
            { "type": "keyword", "value": "or", "max": 0, "fine": 0, "msg": "In dieser Aufgabe ist „OR“ nicht erlaubt…" },
            { "type": "keyword", "value": "not", "max": 0, "fine": 0, "msg": "In dieser Aufgabe ist „NOT“ nicht erlaubt…" },
            { "type": "keyword", "value": "order", "max": 0, "fine": 0, "msg": "In dieser Aufgabe ist „ORDER BY“ nicht erlaubt…" }
        ],
        "checkTermination": [
            { "type": "accept", "unlock": true }
        ]
    },
    {
        "task": "<p><code>guteLandung</code> ist doch ein Wahrheitswert, oder? Also, genau wie eine Gleichung, ist der Attributwert entweder WAHR (also <code>1</code> in SQL) oder FALSCH (<code>0</code> in SQL). Dann können wir doch auch statt der Gleichung nur den Wahrheitswert verwenden, so wie in folgender Abfrage.</p><p>Führe sie aus und beantworte dann die Frage:</p>",
        "code": "SELECT *\n    FROM WEITSPRUNG\n    WHERE guteLandung",
        "readonly": true,
        "tables": TABLES,
        "locked": true,
        "checkCode": [
        ],
        "checkTermination": [
            { "type": "accept", "unlock": true }
        ],
        "questionWrongFine": 1,
        "question": {
            "html": "Worin unterscheidet sich diese Abfrage von den bisher gelernten bzw. genutzten Abfragen?",
            "singlechoice": true,
            "choices": [
                { "html": "Die Auswahlbedingung ist statt einer Gleichung ein Attribut", "correct": true },
                { "html": "Die Auswahlbedingung ist statt einer Gleichung eine Ungleichung" },
                { "html": "Es gibt ein zusätzliches Attribut in der Ergebnistabelle" },
                { "html": "Die Abfrage enthält eine zusätzliche Gleichung" },
                { "html": "Diese Abfrage liefert eine Ergebnistabelle, die mit einer Gleichung als Auswahlbedingung nicht möglich ist", "response": "Diese Abfrage hat die gleiche Ergebnistabelle wie „SELECT * FROM WEITSPRUNG WHERE guteLandung = 1“." }
            ]
        }
    },
    {
        "task": "<p>Eine Auswahlbedingung muss also keineswegs eine Gleichung sein. Es gibt weitere Möglichkeiten. Auch diese Abfrage nutzt eine andere Art von Auswahlbedingung, nämlich eine Ungleichung.</p><p>Schaue dir diese SQL-Abfrage genau an (zunächst ohne sie auszuprobieren!) und beantworte die Frage.</p>",
        "code": "SELECT *\n    FROM WEITSPRUNG\n    WHERE sprungweite > 3.5",
        "readonly": true,
        "tables": TABLES,
        "locked": false,
        "checkCode": [
            { "type": "accept", "accept": false, "fine": 1, "msg": "Du sollst die Abfrage noch nicht ausprobieren!" }
        ],
        "checkTermination": [],
        "questionWrongFine": 1,
        "question": {
            "html": "Welche Datensätze übernimmt wohl diese SQL-Abfrage in die Ergebnistabelle?",
            "singlechoice": true,
            "choices": [
                { "html": "Nur Datensätze, bei denen die Sprungweite mehr als ", "type": "number", "min": 0, "max": 10, "step": 0.01, "accept": "3.5", "unit": " m beträgt.", "correct": true },
                { "html": "Nur Datensätze, bei denen die Sprungweite weniger als ", "type": "number", "min": 0, "max": 10, "step": 0.01, "accept": "3.5", "unit": " m beträgt." },
                { "html": "Nur Datensätze, bei denen die Sprungweite exakt ", "type": "number", "min": 0, "max": 10, "step": 0.01, "accept": "3.5", "unit": " m beträgt." },
                { "html": "Nur Datensätze, bei denen die Sprungweite mindestens ", "type": "number", "min": 0, "max": 10, "step": 0.01, "accept": "3.5", "unit": " m beträgt." },
                { "html": "Nur Datensätze, bei denen die Sprungweite höchstens ", "type": "number", "min": 0, "max": 10, "step": 0.01, "accept": "3.5", "unit": " m beträgt." }
            ]
        }
    },
    {
        "task": "Probiere nun diese neue SQL-Abfrage aus.",
        "code": "SELECT *\n    FROM WEITSPRUNG\n    WHERE sprungweite > 3.5",
        "readonly": true,
        "tables": TABLES,
        "locked": true,
        "checkCode": [
        ],
        "checkTermination": [
            { "type": "accept", "unlock": true }
        ]
    },
    {
        "task": "<p>Cemals bester Sprung war exakt vier Meter lang. Schreibe eine Abfrage die Name und Sprungweite aller Datensätze anzeigt, bei denen die Sprungweite länger ist.</p>",
        "keepCode": true,
        "code": "SELECT *\n    FROM WEITSPRUNG\n    WHERE sprungweite > 3.5",
        "tables": TABLES,
        "locked": true,
        "checkCode": [
            { "type": "keyword", "value": "select", "max": 1, "fine": 0, "msg": "In dieser Aufgabe sind verschachtelte Abfragen nicht erlaubt…" },
            { "type": "keyword", "value": "as", "max": 0, "fine": 0, "msg": "In dieser Aufgabe ist „AS“ nicht erlaubt…" },
            { "type": "keyword", "value": "and", "max": 0, "fine": 0, "msg": "In dieser Aufgabe ist „AND“ nicht erlaubt…" },
            { "type": "keyword", "value": "or", "max": 0, "fine": 0, "msg": "In dieser Aufgabe ist „OR“ nicht erlaubt…" },
            { "type": "keyword", "value": "not", "max": 0, "fine": 0, "msg": "In dieser Aufgabe ist „NOT“ nicht erlaubt…" },
            { "type": "keyword", "value": "order", "max": 0, "fine": 0, "msg": "In dieser Aufgabe ist „ORDER BY“ nicht erlaubt…" }
        ],
        "checkTermination": [
            { "type": "attributeCount", "value": 2, "fine": 1, "msg": "Die Ergebnistabelle nur die Attribute „name“ und „sprungweite„ enthalten" },
            { "type": "attributeName", "index": 0, "value": "name", "fine": 1, "msg": "Der Name muss das erste Attribut sein" },
            { "type": "attributeName", "index": 1, "value": "sprungweite", "fine": 1, "msg": "Das zweite Attribut muss die Sprungweite sein" },
            { "type": "and", "value": [
                { "type": "compareQuery", "value": "sprungweite > 4", "substring": true },
                { "type": "compareQuery", "value": "4 < sprungweite", "substring": true },
                { "type": "compareQuery", "value": "4.0 < sprungweite", "substring": true }
            ], "fine": 1, "msg": "Die Abfragebedingung muss die wirklich passende Ungleichung sein…" },
            { "type": "sameResult", "value": "SELECT name, sprungweite FROM WEITSPRUNG WHERE sprungweite > 4", "fine": 1 },
            { "type": "accept", "unlock": true }
        ]
    },
    {
        "task": "<p>Statt Größer als Vergleichsoperator ist auch Kleiner (<code>&lt;</code>), Größergleich (<code>&gt;=</code>) und Kleinergleich (<code>&lt;=</code>) erlaubt. Beachte, die korrekte Schreibweise von Größergleich und Kleinergleich!</p><p>Ändere nun die Abfrage so ab, dass auch der 4 m-Sprung in der Ergebnistabelle steht. Also Name und Sprungweite zu allen Sprüngen mit <em>mindestens</em> vier Metern Länge.</p>",
        "keepCode": true,
        "code": "SELECT name, sprungweite\n    FROM WEITSPRUNG\n    WHERE sprungweite > 4",
        "tables": TABLES,
        "locked": true,
        "checkCode": [
            { "type": "keyword", "value": "select", "max": 1, "fine": 0, "msg": "In dieser Aufgabe sind verschachtelte Abfragen nicht erlaubt…" },
            { "type": "keyword", "value": "as", "max": 0, "fine": 0, "msg": "In dieser Aufgabe ist „AS“ nicht erlaubt…" },
            { "type": "keyword", "value": "and", "max": 0, "fine": 0, "msg": "In dieser Aufgabe ist „AND“ nicht erlaubt…" },
            { "type": "keyword", "value": "or", "max": 0, "fine": 0, "msg": "In dieser Aufgabe ist „OR“ nicht erlaubt…" },
            { "type": "keyword", "value": "not", "max": 0, "fine": 0, "msg": "In dieser Aufgabe ist „NOT“ nicht erlaubt…" },
            { "type": "keyword", "value": "order", "max": 0, "fine": 0, "msg": "In dieser Aufgabe ist „ORDER BY“ nicht erlaubt…" }
        ],
        "checkTermination": [
            { "type": "attributeCount", "value": 2, "fine": 1, "msg": "Die Ergebnistabelle nur die Attribute „name“ und „sprungweite„ enthalten" },
            { "type": "attributeName", "index": 0, "value": "name", "fine": 1, "msg": "Der Name muss das erste Attribut sein" },
            { "type": "attributeName", "index": 1, "value": "sprungweite", "fine": 1, "msg": "Das zweite Attribut muss die Sprungweite sein" },
            { "type": "and", "value": [
                { "type": "compareQuery", "value": "sprungweite >= 4", "substring": true },
                { "type": "compareQuery", "value": "4 <= sprungweite", "substring": true },
                { "type": "compareQuery", "value": "4.0 <= sprungweite", "substring": true }
            ], "fine": 1, "msg": "Die Abfragebedingung muss die wirklich passende Ungleichung sein…" },
            { "type": "sameResult", "value": "SELECT name, sprungweite FROM WEITSPRUNG WHERE sprungweite >= 4", "fine": 1 },
            { "type": "accept", "unlock": true }
        ]
    },
    {
        "task": "<p>Nur zum Üben: Verfasse und teste noch schnell eine Abfrage, die von allen Datensätzen zu den ersten beiden Versuchen zuerst alle Sprungweiten enthält und dann, ob die Landung gut war.</p>",
        "keepCode": true,
        "code": "SELECT *\n    FROM WEITSPRUNG\n    WHERE sprungweite >= 4",
        "tables": TABLES,
        "locked": true,
        "checkCode": [
            { "type": "keyword", "value": "select", "max": 1, "fine": 0, "msg": "In dieser Aufgabe sind verschachtelte Abfragen nicht erlaubt…" },
            { "type": "keyword", "value": "as", "max": 0, "fine": 0, "msg": "In dieser Aufgabe ist „AS“ nicht erlaubt…" },
            { "type": "keyword", "value": "and", "max": 0, "fine": 0, "msg": "In dieser Aufgabe ist „AND“ nicht erlaubt…" },
            { "type": "keyword", "value": "or", "max": 0, "fine": 0, "msg": "In dieser Aufgabe ist „OR“ nicht erlaubt…" },
            { "type": "keyword", "value": "not", "max": 0, "fine": 0, "msg": "In dieser Aufgabe ist „NOT“ nicht erlaubt…" },
            { "type": "keyword", "value": "order", "max": 0, "fine": 0, "msg": "In dieser Aufgabe ist „ORDER BY“ nicht erlaubt…" }
        ],
        "checkTermination": [
            { "type": "attributeCount", "value": 2, "fine": 1, "msg": "Nur „sprungweite“ und „guteLandung“ sollen in der Ergebnistabelle stehen" },
            { "type": "attributeName", "index": 0, "value": "sprungweite", "fine": 1, "msg": "Das erste Attribut muss „sprungweite“ sein" },
            { "type": "attributeName", "index": 1, "value": "guteLandung", "fine": 1, "msg": "Das zweite Attribut muss „guteLandung“ sein" },
            { "type": "sameResult", "value": "SELECT sprungweite, guteLandung FROM WEITSPRUNG WHERE versuch < 3", "fine": 1 },
            { "type": "accept", "unlock": true }
        ]
    },
    {
        "task": "<p>Auch <code>&lt;&gt;</code> ist ein Vergleichsoperator: Er prüft, ob etwas kleiner oder größer ist. Also auf <em>Ungleichheit</em>.</p><p>Nutze diesen Vergleichsoperator, um eine SQL-Abfrage für folgende Frage zu verfassen: Welche Sprungweiten gab es, wenn die Sprungweiten des zweiten Versuchs nicht mitgezählt werden?</p>",
        "keepCode": true,
        "code": "SELECT sprungweite, guteLandung\n    FROM WEITSPRUNG\n    WHERE versuch < 3",
        "tables": TABLES,
        "locked": true,
        "checkCode": [
            { "type": "keyword", "value": "select", "max": 1, "fine": 0, "msg": "In dieser Aufgabe sind verschachtelte Abfragen nicht erlaubt…" },
            { "type": "keyword", "value": "as", "max": 0, "fine": 0, "msg": "In dieser Aufgabe ist „AS“ nicht erlaubt…" },
            { "type": "keyword", "value": "and", "max": 0, "fine": 0, "msg": "In dieser Aufgabe ist „AND“ nicht erlaubt…" },
            { "type": "keyword", "value": "or", "max": 0, "fine": 0, "msg": "In dieser Aufgabe ist „OR“ nicht erlaubt…" },
            { "type": "keyword", "value": "not", "max": 0, "fine": 0, "msg": "In dieser Aufgabe ist „NOT“ nicht erlaubt…" },
            { "type": "keyword", "value": "order", "max": 0, "fine": 0, "msg": "In dieser Aufgabe ist „ORDER BY“ nicht erlaubt…" }
        ],
        "checkTermination": [
            { "type": "attributeCount", "value": 1, "fine": 1, "msg": "Nur die Sprungweiten sollen in die Ergebnistabelle" },
            { "type": "attributeName", "index": 0, "value": "sprungweite", "fine": 1, "msg": "Die Sprungweiten sollen in die Ergebnistabelle" },
            { "type": "compareQuery", "value": "<>", "substring": true, "fine": 1, "msg": "Verwende den Ungleichheitsoperator „<>“" },
            { "type": "and", "value": [
                { "type": "sameResult", "value": "SELECT sprungweite FROM WEITSPRUNG WHERE versuch <> 2" },
                { "type": "sameResult", "value": "SELECT DISTINCT sprungweite FROM WEITSPRUNG WHERE versuch <> 2" }
            ], "fine": 1 },
            { "type": "accept", "unlock": true }
        ]
    },
    {
        "task": "<p>Gleichungen und Ungleichungen können natürlich auch komplexer sein: Schreibe eine SQL-Abfrage, die <code>name</code> und <code>versuch</code> von den Datensätzen liefert, bei denen die Sprungweite in Metern <em>nicht</em> doppelt so groß ist, wie die Versuchsnummer.</p>",
        "keepCode": true,
        "code": "SELECT sprungweite\n    FROM WEITSPRUNG\n    WHERE versuch <> 2",
        "tables": TABLES,
        "locked": true,
        "checkCode": [
            { "type": "keyword", "value": "select", "max": 1, "fine": 0, "msg": "In dieser Aufgabe sind verschachtelte Abfragen nicht erlaubt…" },
            { "type": "keyword", "value": "as", "max": 0, "fine": 0, "msg": "In dieser Aufgabe ist „AS“ nicht erlaubt…" },
            { "type": "keyword", "value": "and", "max": 0, "fine": 0, "msg": "In dieser Aufgabe ist „AND“ nicht erlaubt…" },
            { "type": "keyword", "value": "or", "max": 0, "fine": 0, "msg": "In dieser Aufgabe ist „OR“ nicht erlaubt…" },
            { "type": "keyword", "value": "not", "max": 0, "fine": 0, "msg": "In dieser Aufgabe ist „NOT“ nicht erlaubt…" },
            { "type": "keyword", "value": "order", "max": 0, "fine": 0, "msg": "In dieser Aufgabe ist „ORDER BY“ nicht erlaubt…" }
        ],
        "checkTermination": [
            { "type": "attributeCount", "value": 2, "fine": 1, "msg": "Nur Name und Versuchsnummer sollen in die Ergebnistabelle" },
            { "type": "attributeName", "index": 0, "value": "name", "fine": 1, "msg": "„name“ muss das erste Attribut sein" },
            { "type": "attributeName", "index": 1, "value": "versuch", "fine": 1, "msg": "„verszch“ muss das zweite Attribut sein" },
            { "type": "sameResult", "value": "SELECT name, versuch FROM WEITSPRUNG WHERE versuch * 2 <> sprungweite", "fine": 1 },
            { "type": "accept", "unlock": true }
        ]
    },
    {
        "task": "<p>Eine schlechte Landung kostet mindestens 20 cm an Sprungweite. Verstehst du nun, was diese Abfrage bewirkt? Du kannst sie ausprobieren, musst aber nicht:</p>",
        "code": "SELECT name\n    FROM WEITSPRUNG\n    WHERE sprungweite + (1 - guteLandung) * 0.20 > 3.5",
        "readonly": true,
        "tables": TABLES,
        "locked": false,
        "checkCode": [],
        "checkTermination": [],
        "questionWrongFine": 1,
        "question": {
            "html": "Von welchen Personen stehen die Namen in der Ergebnistabelle?",
            "singlechoice": true,
            "response": "„1 - guteLandung“ ergibt für Datensätze mit einer guten Landung „0“, für die ohne gute Landung „1“. Bei den Datensätzen mit guter Landung ist folglich „sprungweite + (1 - guteLandung) * 0.20“ einfach nur die Sprungweite. Bei denen ohne guter Landung werden zur Sprungweite in Metern noch 20 cm dazugezählt.",
            "choices": [
                { "html": "Nur diejenigen, die mindestens ", "type": "number", "min": 0, "max": 10, "step": 0.01, "accept": "3.5", "unit": " m gesprungen sind &dash; oder gesprungen wären, wenn ihnen eine gute Landung geglückt wäre.", "correct": true },
                { "html": "Nur diejenigen, die mindestens ", "type": "number", "min": 0, "max": 10, "step": 0.01, "accept": "3.5", "unit": " m gesprungen sind und denen eine gute Landung geglückt ist." },
                { "html": "Nur diejenigen, denen keine gute Landung gelungen ist, die aber mindestens ", "type": "number", "min": 0, "max": 10, "step": 0.01, "accept": "3.5", "unit": " m gesprungen sind, wenn man ihre Sprungweite um 20 cm erhöht." },
                { "html": "Alle" },
                { "html": "Keine" }
            ]
        }
    },
    {
        "task": "<p>Auch Ungleichungen <em>mit Zeichenketten</em> sind in SQL möglich. Probiere das gleich aus und schreibe eine Abfrage, die alle nicht Dora betreffenden Datensätze liefert.</p>",
        "code": "SELECT name\n    FROM WEITSPRUNG\n    WHERE sprungweite + (1 - guteLandung) * 0.20 > 3.5",
        "tables": TABLES,
        "locked": true,
        "checkCode": [
            { "type": "keyword", "value": "select", "max": 1, "fine": 0, "msg": "In dieser Aufgabe sind verschachtelte Abfragen nicht erlaubt…" },
            { "type": "keyword", "value": "as", "max": 0, "fine": 0, "msg": "In dieser Aufgabe ist „AS“ nicht erlaubt…" },
            { "type": "keyword", "value": "and", "max": 0, "fine": 0, "msg": "In dieser Aufgabe ist „AND“ nicht erlaubt…" },
            { "type": "keyword", "value": "or", "max": 0, "fine": 0, "msg": "In dieser Aufgabe ist „OR“ nicht erlaubt…" },
            { "type": "keyword", "value": "not", "max": 0, "fine": 0, "msg": "In dieser Aufgabe ist „NOT“ nicht erlaubt…" },
            { "type": "keyword", "value": "order", "max": 0, "fine": 0, "msg": "In dieser Aufgabe ist „ORDER BY“ nicht erlaubt…" }
        ],
        "checkTermination": [
            { "type": "attributeCount", "value": 4, "fine": 1, "msg": "Alle Attribute der Datenbanktabelle sollen in die Ergebnistabelle" },
            { "type": "attributeName", "index": 0, "value": "name", "fine": 1, "msg": "„name“ muss das erste Attribut sein" },
            { "type": "attributeName", "index": 1, "value": "versuch", "fine": 1, "msg": "„versuch“ muss das zweite Attribut sein" },
            { "type": "attributeName", "index": 2, "value": "sprungweite", "fine": 1, "msg": "„sprungweite“ muss das dritte Attribut sein" },
            { "type": "attributeName", "index": 3, "value": "guteLandung", "fine": 1, "msg": "„guteLandung“ muss das vierte Attribut sein" },
            { "type": "sameResult", "value": "SELECT * FROM WEITSPRUNG WHERE name <> 'Dora'", "fine": 1 },
            { "type": "accept", "unlock": true }
        ]
    },
    {
        "task": "Was wohl eine Auswahlbedingung bewirkt, die eine Ungleichung ist und Zeichenketten vergleicht? Finde es heraus. Du kannst beliebig oft beliebige Abfragen testen, bevor du die Frage beantwortest.",
        "code": "SELECT *\n    FROM WEITSPRUNG\n    WHERE name <= 'Dora'",
        "readonly": false,
        "tables": TABLES,
        "locked": true,
        "checkCode": [
        ],
        "checkTermination": [
            { "type": "accept", "unlock": true }
        ],
        "questionWrongFine": 1,
        "question": {
            "html": "Was bewirkt die Auswahlbedingung <code> name &lt; 'Dora'</code>?",
            "singlechoice": true,
            "choices": [
                { "html": "Bei alphabetischer Sortierung muss der Name <em>vor</em> „Dora“ stehen", "correct": true },
                { "html": "Bei alphabetischer Sortierung muss der Name <em>nach</em> „Dora“ stehen" },
                { "html": "Die Sprungweite muss <em>größer</em> sein als bei „Dora“" },
                { "html": "Die Sprungweite muss <em>kleiner</em> sein als bei „Dora“" },
                { "html": "Der Name muss <em>mehr</em> Buchstaben haben als „Dora“" },
                { "html": "Der Name muss <em>weniger</em> Buchstaben haben als „Dora“" }
            ]
        }
    }
];

window.sqlCodingTask = {
    levels: LEVELS
};
})(window);
